@@ -4,7 +4,9 @@ use 5.008;
 use strict;
 use warnings;
 use Wx ':everything';
+use Wx::STC ();
 use Wx::HTML ();
+use Wx::Grid ();
 use t::lib::Custom ();
 use t::lib::MyClass ();
 
@@ -120,6 +122,14 @@ sub new {
 		Wx::Bitmap->new( "padre-plugin.png", Wx::wxBITMAP_TYPE_ANY )
 	);
 
+	$self->{m_spinBtn1} = Wx::SpinButton->new(
+		$self,
+		-1,
+		Wx::wxDefaultPosition,
+		Wx::wxDefaultSize,
+		Wx::wxSP_HORIZONTAL,
+	);
+
 	$self->{m_staticline1} = Wx::StaticLine->new(
 		$self,
 		-1,
@@ -354,6 +364,35 @@ sub new {
 	);
 	$self->{m_radioBtn4}->SetValue(1);
 
+	$self->{m_animCtrl1} = Wx::AnimationCtrl->new(
+		$self->{m_panel9},
+		-1,
+		Wx::wxNullAnimation,
+		Wx::wxDefaultPosition,
+		Wx::wxDefaultSize,
+		Wx::wxAC_DEFAULT_STYLE,
+	);
+	$self->{m_animCtrl1}->SetInactiveBitmap(
+		Wx::Bitmap->new( "padre-plugin.png", Wx::wxBITMAP_TYPE_ANY )
+	);
+
+	$self->{m_panel11} = Wx::Panel->new(
+		$self->{m_notebook1},
+		-1,
+		Wx::wxDefaultPosition,
+		Wx::wxDefaultSize,
+		Wx::wxTAB_TRAVERSAL,
+	);
+
+	$self->{m_calendar2} = Wx::CalendarCtrl->new(
+		$self->{m_panel11},
+		-1,
+		undef,
+		Wx::wxDefaultPosition,
+		Wx::wxDefaultSize,
+		Wx::wxCAL_MONDAY_FIRST | Wx::wxCAL_SHOW_HOLIDAYS | Wx::wxCAL_SHOW_SURROUNDING_WEEKS,
+	);
+
 	$self->{m_listbook1} = Wx::Listbook->new(
 		$self,
 		-1,
@@ -585,12 +624,130 @@ sub new {
 	);
 	$self->{m_gauge1}->SetValue(85);
 
+	$self->{m_choicebook1} = Wx::Choicebook->new(
+		$self,
+		-1,
+		Wx::wxDefaultPosition,
+		Wx::wxDefaultSize,
+		Wx::wxCHB_DEFAULT,
+	);
+
+	$self->{m_panel13} = Wx::Panel->new(
+		$self->{m_choicebook1},
+		-1,
+		Wx::wxDefaultPosition,
+		Wx::wxDefaultSize,
+		Wx::wxTAB_TRAVERSAL,
+	);
+
+	$self->{m_richText1} = Wx::RichTextCtrl->new(
+		$self->{m_panel13},
+		-1,
+		undef,
+		Wx::wxDefaultPosition,
+		Wx::wxDefaultSize,
+		Wx::wxVSCROLL | Wx::wxHSCROLL | Wx::wxNO_BORDER | Wx::wxWANTS_CHARS,
+	);
+
+	$self->{m_panel12} = Wx::Panel->new(
+		$self->{m_choicebook1},
+		-1,
+		Wx::wxDefaultPosition,
+		Wx::wxDefaultSize,
+		Wx::wxTAB_TRAVERSAL,
+	);
+
+	$self->{m_grid1} = Wx::Grid->new(
+		$self->{m_panel12},
+		-1,
+		Wx::wxDefaultPosition,
+		Wx::wxDefaultSize,
+	);
+	$self->{m_grid1}->CreateGrid( 5, 5 );
+	$self->{m_grid1}->EnableEditing(1);
+	$self->{m_grid1}->EnableGridLines(1);
+	$self->{m_grid1}->SetGridLineColour(
+		Wx::Colour->new( 255, 0, 0 )
+	);
+	$self->{m_grid1}->EnableDragGridSize(0);
+	$self->{m_grid1}->SetMargins( 1, 0 );
+	$self->{m_grid1}->SetColSize( 0, 10 );
+	$self->{m_grid1}->SetColSize( 1, 20 );
+	$self->{m_grid1}->SetColSize( 2, 30 );
+	$self->{m_grid1}->SetColSize( 3, 40 );
+	$self->{m_grid1}->SetColSize( 4, 50 );
+	$self->{m_grid1}->AutoSizeColumns;
+	$self->{m_grid1}->EnableDragColMove(0);
+	$self->{m_grid1}->EnableDragColSize(1);
+	$self->{m_grid1}->SetColLabelSize(30);
+	$self->{m_grid1}->SetColLabelValue( 0, Wx::gettext("A") );
+	$self->{m_grid1}->SetColLabelValue( 1, Wx::gettext("B") );
+	$self->{m_grid1}->SetColLabelValue( 2, Wx::gettext("C") );
+	$self->{m_grid1}->SetColLabelValue( 3, Wx::gettext("D") );
+	$self->{m_grid1}->SetColLabelValue( 4, Wx::gettext("E") );
+	$self->{m_grid1}->SetColLabelAlignment( Wx::wxALIGN_CENTRE, Wx::wxALIGN_CENTRE );
+	$self->{m_grid1}->SetRowSize( 0, 10 );
+	$self->{m_grid1}->SetRowSize( 1, 20 );
+	$self->{m_grid1}->SetRowSize( 2, 30 );
+	$self->{m_grid1}->SetRowSize( 3, 40 );
+	$self->{m_grid1}->SetRowSize( 4, 50 );
+	$self->{m_grid1}->AutoSizeRows;
+	$self->{m_grid1}->EnableDragRowSize(1);
+	$self->{m_grid1}->SetRowLabelValue( 0, Wx::gettext(1) );
+	$self->{m_grid1}->SetRowLabelValue( 1, Wx::gettext(2) );
+	$self->{m_grid1}->SetRowLabelValue( 2, Wx::gettext(3) );
+	$self->{m_grid1}->SetRowLabelValue( 3, Wx::gettext(4) );
+	$self->{m_grid1}->SetRowLabelValue( 4, Wx::gettext(5) );
+	$self->{m_grid1}->SetRowLabelAlignment( Wx::wxALIGN_CENTRE, Wx::wxALIGN_CENTRE );
+	$self->{m_grid1}->SetLabelBackgroundColour(
+		Wx::SystemSettings::GetColour( Wx::wxSYS_COLOUR_INFOBK )
+	);
+	$self->{m_grid1}->SetLabelFont(
+		Wx::Font->new( Wx::wxNORMAL_FONT->GetPointSize, 75, 90, 90, 0, "" )
+	);
+	$self->{m_grid1}->SetLabelTextColour(
+		Wx::Colour->new( 0, 255, 0 )
+	);
+	$self->{m_grid1}->SetDefaultCellBackgroundColour(
+		Wx::SystemSettings::GetColour( Wx::wxSYS_COLOUR_WINDOW )
+	);
+	$self->{m_grid1}->SetDefaultCellAlignment( Wx::wxALIGN_LEFT, Wx::wxALIGN_TOP );
+
+	$self->{m_scrollBar1} = Wx::ScrollBar->new(
+		$self->{m_panel12},
+		-1,
+		Wx::wxDefaultPosition,
+		Wx::wxDefaultSize,
+		Wx::wxSB_HORIZONTAL,
+	);
+
+	$self->{m_panel131} = Wx::Panel->new(
+		$self->{m_choicebook1},
+		-1,
+		Wx::wxDefaultPosition,
+		Wx::wxDefaultSize,
+		Wx::wxTAB_TRAVERSAL,
+	);
+
+	$self->{m_genericDirCtrl1} = Wx::GenericDirCtrl->new(
+		$self->{m_panel131},
+		-1,
+		"default/folder",
+		Wx::wxDefaultPosition,
+		Wx::wxDefaultSize,
+		Wx::wxDIRCTRL_3D_INTERNAL | Wx::wxSUNKEN_BORDER,
+		"*.txt",
+		0,
+	);
+	$self->{m_genericDirCtrl1}->ShowHidden(0);
+
 	my $bSizer10 = Wx::BoxSizer->new(Wx::wxHORIZONTAL);
 	$bSizer10->Add( $self->{m_bitmap1}, 0, Wx::wxALL, 5 );
 	$bSizer10->Add( $self->{m_textCtrl1}, 0, Wx::wxALL, 5 );
 	$bSizer10->Add( $self->{m_button1}, 0, Wx::wxALL, 5 );
 	$bSizer10->Add( $self->{m_toggleBtn1}, 0, Wx::wxALL, 5 );
 	$bSizer10->Add( $self->{m_bpButton1}, 0, Wx::wxALL, 5 );
+	$bSizer10->Add( $self->{m_spinBtn1}, 0, Wx::wxALL, 5 );
 
 	my $fgSizer1 = Wx::FlexGridSizer->new( 1, 2, 3, 4 );
 	$fgSizer1->AddGrowableCol(0);
@@ -649,13 +806,22 @@ sub new {
 	$bSizer12->Add( $self->{m_radioBtn2}, 0, Wx::wxALL, 5 );
 	$bSizer12->Add( $self->{m_radioBtn3}, 0, Wx::wxALL, 5 );
 	$bSizer12->Add( $self->{m_radioBtn4}, 0, Wx::wxALL, 5 );
+	$bSizer12->Add( $self->{m_animCtrl1}, 0, Wx::wxALL, 5 );
 
 	$self->{m_panel9}->SetSizer($bSizer12);
 	$self->{m_panel9}->Layout;
 	$bSizer12->Fit($self->{m_panel9});
 
+	my $bSizer14 = Wx::BoxSizer->new(Wx::wxVERTICAL);
+	$bSizer14->Add( $self->{m_calendar2}, 0, Wx::wxALL, 5 );
+
+	$self->{m_panel11}->SetSizer($bSizer14);
+	$self->{m_panel11}->Layout;
+	$bSizer14->Fit($self->{m_panel11});
+
 	$self->{m_notebook1}->AddPage( $self->{m_panel8}, Wx::gettext("Checkboxes"), 1 );
 	$self->{m_notebook1}->AddPage( $self->{m_panel9}, Wx::gettext("Empty Tree"), 0 );
+	$self->{m_notebook1}->AddPage( $self->{m_panel11}, Wx::gettext("Calendar"), 0 );
 
 	my $bSizer3 = Wx::BoxSizer->new(Wx::wxVERTICAL);
 	$bSizer3->Add( $self->{m_staticText2}, 0, Wx::wxALL, 5 );
@@ -703,6 +869,32 @@ sub new {
 	$self->{m_listbook2}->AddPage( $self->{m_panel6}, Wx::gettext("Page One"), 0 );
 	$self->{m_listbook2}->AddPage( $self->{m_panel7}, Wx::gettext("Page Two"), 1 );
 
+	my $bSizer15 = Wx::BoxSizer->new(Wx::wxVERTICAL);
+	$bSizer15->Add( $self->{m_richText1}, 1, Wx::wxEXPAND, 5 );
+
+	$self->{m_panel13}->SetSizer($bSizer15);
+	$self->{m_panel13}->Layout;
+	$bSizer15->Fit($self->{m_panel13});
+
+	my $bSizer151 = Wx::BoxSizer->new(Wx::wxVERTICAL);
+	$bSizer151->Add( $self->{m_grid1}, 0, 0, 5 );
+	$bSizer151->Add( $self->{m_scrollBar1}, 0, Wx::wxEXPAND, 5 );
+
+	$self->{m_panel12}->SetSizer($bSizer151);
+	$self->{m_panel12}->Layout;
+	$bSizer151->Fit($self->{m_panel12});
+
+	my $bSizer16 = Wx::BoxSizer->new(Wx::wxVERTICAL);
+	$bSizer16->Add( $self->{m_genericDirCtrl1}, 1, Wx::wxEXPAND | Wx::wxALL, 5 );
+
+	$self->{m_panel131}->SetSizer($bSizer16);
+	$self->{m_panel131}->Layout;
+	$bSizer16->Fit($self->{m_panel131});
+
+	$self->{m_choicebook1}->AddPage( $self->{m_panel13}, Wx::gettext("Rich Text Control"), 1 );
+	$self->{m_choicebook1}->AddPage( $self->{m_panel12}, Wx::gettext("Grid"), 0 );
+	$self->{m_choicebook1}->AddPage( $self->{m_panel131}, Wx::gettext("Directory"), 0 );
+
 	my $bSizer2 = Wx::BoxSizer->new(Wx::wxVERTICAL);
 	$bSizer2->Add( $self->{m_staticText1}, 0, Wx::wxALL, 5 );
 	$bSizer2->Add( 10, 5, 0, Wx::wxEXPAND, 5 );
@@ -712,6 +904,7 @@ sub new {
 	$bSizer2->Add( $self->{m_notebook1}, 0, Wx::wxEXPAND | Wx::wxALL, 5 );
 	$bSizer2->Add( $self->{m_listbook1}, 0, Wx::wxEXPAND | Wx::wxALL, 5 );
 	$bSizer2->Add( $self->{m_listbook2}, 0, Wx::wxEXPAND | Wx::wxALL, 5 );
+	$bSizer2->Add( $self->{m_choicebook1}, 1, Wx::wxEXPAND | Wx::wxALL, 5 );
 
 	my $bSizer1 = Wx::BoxSizer->new(Wx::wxHORIZONTAL);
 	$bSizer1->Add( $bSizer2, 1, Wx::wxEXPAND, 5 );
